Authors
=======

Soapfish was originally written by Damian Powązka while working at Flight Data
Services. At that time it was called Soapbox and from February 2012 was
maintained by Flight Data Services. The project was forked in November 2013 by
Felix Schwarz (based on the last BSD-licensed commit), after which a large
number of new features were added by Thomas Recouvreux and Xavier Fernandez
from Polyconseil between February and June 2014. Iuri de Silvio from Pricez
added some features and fixed numerous bugs during 2015. In early 2016, Flight
Data Services retired the unmaintained Soapbox project in favour of Soapfish.

**Original Author:**

- Damian Powązka (Flight Data Services)

**Maintainers:**

- Felix Schwarz (sponsored by Rechenzentrum für Berliner Apotheken Stein & Reichwald GmbH)
- Nick Pope (Flight Data Services)
- Iuri de Silvio (Pricez)

**Major Contributors:**

- Thomas Recouvreux (Polyconseil)
- Xavier Fernandez (Polyconseil)
